@@ -30,7 +30,7 @@
 #'
 #' @examples
 #' library(tidyr)
-#' 
+#'
 #' # t test for number of hours worked per week
 #' # by college degree status
 #' gss %>%
@@ -40,45 +40,45 @@
 #'       alternative = "two-sided")
 #'
 #' # see vignette("infer") for more explanation of the
-#' # intuition behind the infer package, and vignette("t_test") 
+#' # intuition behind the infer package, and vignette("t_test")
 #' # for more examples of t-tests using infer
 #'
 #' @importFrom rlang f_lhs
 #' @importFrom rlang f_rhs
 #' @importFrom stats as.formula
 #' @export
-t_test <- function(x, formula, 
-                   response = NULL, 
+t_test <- function(x, formula,
+                   response = NULL,
                    explanatory = NULL,
                    order = NULL,
-                   alternative = "two-sided", 
+                   alternative = "two-sided",
                    mu = 0,
                    conf_int = TRUE,
                    conf_level = 0.95,
                    ...) {
   check_conf_level(conf_level)
-  
+
   # convert all character and logical variables to be factor variables
   x <- tibble::as_tibble(x) %>%
     mutate_if(is.character, as.factor) %>%
     mutate_if(is.logical, as.factor)
-  
+
   # parse response and explanatory variables
   response    <- enquo(response)
   explanatory <- enquo(explanatory)
-  x <- parse_variables(x = x, formula = formula, 
+  x <- parse_variables(x = x, formula = formula,
                        response = response, explanatory = explanatory)
-  
+
   # match with old "dot" syntax in t.test
   if (alternative %in% c("two-sided", "two_sided", "two sided")) {
     alternative <- "two.sided"
   }
-  
+
   # two sample
   if (has_explanatory(x)) {
     # if (!is.null(order)) {
-    #   x[[as.character(attr(x, "explanatory"))]] <- factor(explanatory_variable(x), 
-    #                                                       levels = c(order[1], 
+    #   x[[as.character(attr(x, "explanatory"))]] <- factor(explanatory_variable(x),
+    #                                                       levels = c(order[1],
     #                                                                  order[2]),
     #                                                       ordered = TRUE)
     # }
@@ -100,7 +100,7 @@ t_test <- function(x, formula,
                             conf.level = conf_level) %>%
       broom::glance()
   }
-  
+
   if (conf_int) {
     results <- prelim %>%
       dplyr::select(
@@ -113,14 +113,14 @@ t_test <- function(x, formula,
         statistic, t_df = parameter, p_value = p.value, alternative
       )
   }
-  
+
   results
 }
 
 #' Tidy t-test statistic
 #'
 #' @description
-#' 
+#'
 #' A shortcut wrapper function to get the observed test statistic for a t test.
 #'
 #' @param x A data frame that can be coerced into a [tibble][tibble::tibble].
@@ -144,7 +144,7 @@ t_test <- function(x, formula,
 #'
 #' @examples
 #' library(tidyr)
-#' 
+#'
 #' # t test statistic for true mean number of hours worked
 #' # per week of 40
 #' gss %>%
@@ -159,38 +159,38 @@ t_test <- function(x, formula,
 #'       alternative = "two-sided")
 #'
 #' @export
-t_stat <- function(x, formula, 
-                   response = NULL, 
+t_stat <- function(x, formula,
+                   response = NULL,
                    explanatory = NULL,
                    order = NULL,
-                   alternative = "two-sided", 
+                   alternative = "two-sided",
                    mu = 0,
                    conf_int = FALSE,
                    conf_level = 0.95,
                    ...) {
   check_conf_level(conf_level)
-  
+
   # convert all character and logical variables to be factor variables
   x <- tibble::as_tibble(x) %>%
     mutate_if(is.character, as.factor) %>%
     mutate_if(is.logical, as.factor)
-  
+
   # parse response and explanatory variables
   response    <- enquo(response)
   explanatory <- enquo(explanatory)
-  x <- parse_variables(x = x, formula = formula, 
+  x <- parse_variables(x = x, formula = formula,
                        response = response, explanatory = explanatory)
-  
+
   # match with old "dot" syntax in t.test
   if (alternative %in% c("two-sided", "two_sided", "two sided")) {
     alternative <- "two.sided"
   }
-  
+
   # two sample
   if (has_explanatory(x)) {
     # if (!is.null(order)) {
-    #   x[[as.character(attr(x, "explanatory"))]] <- factor(explanatory_variable(x), 
-    #                                                       levels = c(order[1], 
+    #   x[[as.character(attr(x, "explanatory"))]] <- factor(explanatory_variable(x),
+    #                                                       levels = c(order[1],
     #                                                                  order[2]),
     #                                                       ordered = TRUE)
     # }
@@ -212,13 +212,13 @@ t_stat <- function(x, formula,
                             conf.level = conf_level) %>%
       broom::glance()
   }
-  
-  # removed unnecessary if(conf_int) clause; only the statistic itself 
+
+  # removed unnecessary if(conf_int) clause; only the statistic itself
   # was returned regardless
   results <- prelim %>%
     dplyr::select(statistic) %>%
     pull()
-  
+
   results
 }
 
@@ -239,13 +239,13 @@ t_stat <- function(x, formula,
 #' @param ... Additional arguments for [chisq.test()][stats::chisq.test()].
 #'
 #' @examples
-#' # chi-squared test of independence for college completion 
+#' # chi-squared test of independence for college completion
 #' # status depending on one's self-identified income class
 #' chisq_test(gss, college ~ finrela)
-#' 
-#' # chi-squared goodness of fit test on whether self-identified 
+#'
+#' # chi-squared goodness of fit test on whether self-identified
 #' # income class follows a uniform distribution
-#' chisq_test(gss, 
+#' chisq_test(gss,
 #'            response = finrela,
 #'            p = c("far below average" = 1/6,
 #'                  "below average" = 1/6,
@@ -255,35 +255,35 @@ t_stat <- function(x, formula,
 #'                  "DK" = 1/6))
 #'
 #' @export
-chisq_test <- function(x, formula, response = NULL, 
+chisq_test <- function(x, formula, response = NULL,
                        explanatory = NULL, ...) {
   # Parse response and explanatory variables
   response    <- enquo(response)
   explanatory <- enquo(explanatory)
-  x <- parse_variables(x = x, formula = formula, 
+  x <- parse_variables(x = x, formula = formula,
                        response = response, explanatory = explanatory)
-  
+
   if (!(class(response_variable(x)) %in% c("logical", "character", "factor"))) {
     stop_glue(
       'The response variable of `{attr(x, "response")}` is not appropriate\n',
       "since the response variable is expected to be categorical."
     )
   }
-  if (has_explanatory(x) && 
+  if (has_explanatory(x) &&
       !(class(explanatory_variable(x)) %in% c("logical", "character", "factor"))) {
     stop_glue(
       'The explanatory variable of `{attr(x, "explanatory")}` is not appropriate\n',
       "since the explanatory variable is expected to be categorical."
     )
   }
-  
+
   x <- x %>%
     select(one_of(c(
       as.character((attr(x, "response"))), as.character(attr(x, "explanatory"))
     ))) %>%
     mutate_if(is.character, as.factor) %>%
     mutate_if(is.logical, as.factor)
-  
+
   stats::chisq.test(table(x), ...) %>%
     broom::glance() %>%
     dplyr::select(statistic, chisq_df = parameter, p_value = p.value)
@@ -307,15 +307,15 @@ chisq_test <- function(x, formula, response = NULL,
 #' @param ... Additional arguments for [chisq.test()][stats::chisq.test()].
 #'
 #' @examples
-#' # chi-squared test statistic for test of independence 
-#' # of college completion status depending and one's 
+#' # chi-squared test statistic for test of independence
+#' # of college completion status depending and one's
 #' # self-identified income class
 #' chisq_stat(gss, college ~ finrela)
-#' 
-#' # chi-squared test statistic for a goodness of fit 
-#' # test on whether self-identified income class 
+#'
+#' # chi-squared test statistic for a goodness of fit
+#' # test on whether self-identified income class
 #' # follows a uniform distribution
-#' chisq_stat(gss, 
+#' chisq_stat(gss,
 #'            response = finrela,
 #'            p = c("far below average" = 1/6,
 #'                  "below average" = 1/6,
@@ -325,35 +325,35 @@ chisq_test <- function(x, formula, response = NULL,
 #'                  "DK" = 1/6))
 #'
 #' @export
-chisq_stat <- function(x, formula, response = NULL, 
+chisq_stat <- function(x, formula, response = NULL,
                        explanatory = NULL, ...) {
   # Parse response and explanatory variables
   response    <- enquo(response)
   explanatory <- enquo(explanatory)
-  x <- parse_variables(x = x, formula = formula, 
+  x <- parse_variables(x = x, formula = formula,
                        response = response, explanatory = explanatory)
-  
+
   if (!(class(response_variable(x)) %in% c("logical", "character", "factor"))) {
     stop_glue(
       'The response variable of `{attr(x, "response")}` is not appropriate\n',
       "since the response variable is expected to be categorical."
     )
   }
-  if (has_explanatory(x) && 
+  if (has_explanatory(x) &&
       !(class(explanatory_variable(x)) %in% c("logical", "character", "factor"))) {
     stop_glue(
       'The explanatory variable of `{attr(x, "explanatory")}` is not appropriate\n',
       "since the response variable is expected to be categorical."
     )
   }
-  
+
   x <- x %>%
     select(one_of(c(
       as.character((attr(x, "response"))), as.character(attr(x, "explanatory"))
     ))) %>%
     mutate_if(is.character, as.factor) %>%
     mutate_if(is.logical, as.factor)
-  
+
   suppressWarnings(stats::chisq.test(table(x), ...)) %>%
     broom::glance() %>%
     dplyr::select(statistic) %>%
@@ -386,55 +386,85 @@ check_conf_level <- function(conf_level) {
 #'   explanatory variable. Optional. This is an alternative to the formula
 #'   interface.
 #' @param order A string vector specifying the order in which the proportions
-#'   should be subtracted, where  `order = c("first", "second")` means 
-#'   `"first" - "second"`. Ignored for one-sample tests, and optional for two 
+#'   should be subtracted, where  `order = c("first", "second")` means
+#'   `"first" - "second"`. Ignored for one-sample tests, and optional for two
 #'   sample tests.
 #' @param alternative Character string giving the direction of the alternative
 #'   hypothesis. Options are `"two-sided"` (default), `"greater"`, or `"less"`.
+#'   Only used when testing the null that a single proportion equals a given
+#'   value, or that two proportions are equal; ignored otherwise.
 #' @param p A numeric vector giving the hypothesized null proportion of
 #' success for each group.
 #' @param conf_int A logical value for whether to report the confidence
 #'   interval or not. `TRUE` by default, ignored if `p` is specified for a
-#'   two-sample test.
+#'   two-sample test. Only used when testing the null that a single
+#'   proportion equals a given value, or that two proportions are equal;
+#'   ignored otherwise.
 #' @param conf_level A numeric value between 0 and 1. Default value is 0.95.
+#'   Only used when testing the null that a single proportion equals a given
+#'   value, or that two proportions are equal; ignored otherwise.
+#' @param success The level of `response` that will be considered a success, as
+#'   a string. Only used when testing the null that a single
+#'   proportion equals a given value, or that two proportions are equal;
+#'   ignored otherwise.
+#' @param correct A logical indicating whether Yates' continuity correction 
+#'   should be applied where possible. If `z = TRUE`, the `correct` argument will 
+#'   be overwritten as `FALSE`. Otherwise defaults to `correct = TRUE`.
+#' @param z A logical value for whether to report the statistic as a standard
+#'   normal deviate or a Pearson's chi-square statistic. \eqn{z^2}  is distributed
+#'   chi-square with 1 degree of freedom, though note that the user will likely
+#'   need to turn off Yates' continuity correction by setting `correct = FALSE`
+#'   to see this connection.
 #' @param ... Additional arguments for [prop.test()][stats::prop.test()].
 #'
 #' @examples
-#' # proportion test for difference in proportions of 
+#' # two-sample proportion test for difference in proportions of
 #' # college completion by respondent sex
-#' prop_test(gss, 
-#'           college ~ sex,  
+#' prop_test(gss,
+#'           college ~ sex,
 #'           order = c("female", "male"))
-#'           
-#' # a one-proportion test for hypothesized null 
+#'
+#' # one-sample proportion test for hypothesized null
 #' # proportion of college completion of .2
 #' prop_test(gss,
 #'           college ~ NULL,
 #'           p = .2)
+#' 
+#' # report as a z-statistic rather than chi-square
+#' # and specify the success level of the response
+#' prop_test(gss,
+#'           college ~ NULL,
+#'           success = "degree",
+#'           p = .2,
+#'           z = TRUE)
 #'
 #' @export
-prop_test <- function(x, formula, 
-                      response = NULL, 
+prop_test <- function(x, formula,
+                      response = NULL,
                       explanatory = NULL,
                       p = NULL,
                       order = NULL,
-                      alternative = "two-sided", 
+                      alternative = "two-sided",
                       conf_int = TRUE,
                       conf_level = 0.95,
+                      success = NULL,
+                      correct = NULL,
+                      z = FALSE,
                       ...) {
   # Parse response and explanatory variables
   response    <- enquo(response)
   explanatory <- enquo(explanatory)
-  x <- parse_variables(x = x, formula = formula, 
+  x <- parse_variables(x = x, formula = formula,
                        response = response, explanatory = explanatory)
-  
+  correct <- if (z) {FALSE} else if (is.null(correct)) {TRUE} else {correct}
+
   if (!(class(response_variable(x)) %in% c("logical", "character", "factor"))) {
     stop_glue(
       'The response variable of `{attr(x, "response")}` is not appropriate\n',
       "since the response variable is expected to be categorical."
     )
   }
-  if (has_explanatory(x) && 
+  if (has_explanatory(x) &&
       !(class(explanatory_variable(x)) %in% c("logical", "character", "factor"))) {
     stop_glue(
       'The explanatory variable of `{attr(x, "explanatory")}` is not appropriate\n',
@@ -445,68 +475,118 @@ prop_test <- function(x, formula,
   if (alternative %in% c("two-sided", "two_sided", "two sided")) {
     alternative <- "two.sided"
   }
-  
+
+  # process "success" arg
+  lvls <- levels(factor(response_variable(x)))
+
+  if (!is.null(success)) {
+    check_type(success, rlang::is_string)
+
+    if (!(success %in% lvls)) {
+      stop_glue('{success} is not a valid level of {attr(x, "response")}.')
+    }
+
+    lvls <- c(success, lvls[lvls != success])
+  } else {
+    success <- lvls[1]
+  }
+
   # two sample
   if (has_explanatory(x)) {
-    
+
     order <- check_order(x, explanatory_variable(x), order, in_calculate = FALSE)
-    
+
     # make a summary table to supply to prop.test
     sum_table <- x %>%
-      select(as.character((attr(x, "response"))), 
+      select(as.character((attr(x, "response"))),
              as.character(attr(x, "explanatory"))) %>%
       mutate_if(is.character, as.factor) %>%
       mutate_if(is.logical, as.factor) %>%
       table()
-    
-    # reorder according to the order argument
-    sum_table <- sum_table[, order]
-    
+
+    # reorder according to the order and success arguments
+    sum_table <- sum_table[lvls, order]
+
     prelim <- stats::prop.test(x = sum_table,
                                alternative = alternative,
                                conf.level = conf_level,
                                p = p,
-                               ...) %>%
-      broom::glance()
+                               correct = correct,
+                               ...)
   } else { # one sample
-    response_tbl <- x %>%
-      select(as.character((attr(x, "response")))) %>%
-      mutate_if(is.character, as.factor) %>%
-      mutate_if(is.logical, as.factor) %>%
+    response_tbl <- response_variable(x) %>%
+      factor() %>%
+      stats::relevel(success) %>%
       table()
-    
+
     if (is.null(p)) {
       message_glue(
         "No `p` argument was hypothesized, so the test will ",
         "assume a null hypothesis `p = .5`."
       )
     }
-    
+
     prelim <- stats::prop.test(x = response_tbl,
                                alternative = alternative,
                                conf.level = conf_level,
                                p = p,
-                               ...) %>%
-      broom::glance()
+                               correct = correct,
+                               ...)
+      
   }
-  
-  if (conf_int & is.null(p)) {
-     results <- prelim %>%
-       dplyr::select(statistic, 
-                     chisq_df = parameter, 
-                     p_value = p.value, 
-                     alternative,
-                     lower_ci = conf.low, 
-                     upper_ci = conf.high)
-    
+
+  if (length(prelim$estimate) <= 2) {
+    if (conf_int & is.null(p)) {
+       results <- prelim %>%
+         broom::glance() %>%
+         dplyr::select(statistic,
+                       chisq_df = parameter,
+                       p_value = p.value,
+                       alternative,
+                       lower_ci = conf.low,
+                       upper_ci = conf.high)
+    } else {
+       results <- prelim %>%
+         broom::glance() %>%
+         dplyr::select(statistic,
+                       chisq_df = parameter,
+                       p_value = p.value,
+                       alternative)
+    }
   } else {
-     results <- prelim %>%
-       dplyr::select(statistic, 
-                     chisq_df = parameter, 
-                     p_value = p.value, 
-                     alternative)
+    results <- prelim %>%
+      broom::glance() %>%
+      dplyr::select(statistic,
+                    chisq_df = parameter,
+                    p_value = p.value)
   }
   
+  if (z) {
+    results <- calculate_z(x, results, success, p, order)
+  }
+
   results
 }
 
+calculate_z <- function(x, results, success, p, order) {
+  exp <- if (has_explanatory(x)) {attr(x, "explanatory")} else {"NULL"}
+  
+  form <- as.formula(paste0(attr(x, "response"), " ~ ", exp))
+  
+  stat <- x %>%
+    specify(formula = form, success = success) %>%
+    hypothesize(
+      null = if (has_explanatory(x)) {"independence"} else {"point"},
+      p = if (is.null(p) && !has_explanatory(x)) {.5} else {p}
+    ) %>%
+    calculate(
+      stat = "z",
+      order = if (has_explanatory(x)) {order} else {NULL}
+    ) %>%
+    dplyr::pull()
+  
+  results$statistic <- stat
+  results$chisq_df <- NULL
+  
+  results
+}
