@@ -12,41 +12,53 @@ test_that("direction is appropriate", {
 })
 
 test_that("get_p_value works", {
-  expect_equal(get_p_value(test_df, 4, "right")[[1]][1], 5/20)
-  expect_equal(get_p_value(test_df, 4, "left")[[1]][1], 17/20)
-  expect_equal(get_p_value(test_df, 4, "both")[[1]][1], 10/20)
+  expect_equal(get_p_value(test_df, 4, "right")[[1]][1], 5/20, tolerance = eps)
+  expect_equal(get_p_value(test_df, 4, "left")[[1]][1], 17/20, tolerance = eps)
+  expect_equal(get_p_value(test_df, 4, "both")[[1]][1], 10/20, tolerance = eps)
   
-  expect_equal(get_p_value(test_df, 0, "right")[[1]][1], 14/20)
-  expect_equal(get_p_value(test_df, 0, "left")[[1]][1], 12/20)
+  expect_equal(get_p_value(test_df, 0, "right")[[1]][1], 14/20, tolerance = eps)
+  expect_equal(get_p_value(test_df, 0, "left")[[1]][1], 12/20, tolerance = eps)
   # This is also a check for not returning value more than 1
-  expect_equal(get_p_value(test_df, 0, "both")[[1]][1], 1)
+  expect_equal(get_p_value(test_df, 0, "both")[[1]][1], 1, tolerance = eps)
   
-  expect_equal(get_p_value(test_df, -3.999, "right")[[1]][1], 16/20)
-  expect_equal(get_p_value(test_df, -3.999, "left")[[1]][1], 4/20)
-  expect_equal(get_p_value(test_df, -3.999, "both")[[1]][1], 8/20)
+  expect_equal(get_p_value(test_df, -3.999, "right")[[1]][1], 16/20, tolerance = eps)
+  expect_equal(get_p_value(test_df, -3.999, "left")[[1]][1], 4/20, tolerance = eps)
+  expect_equal(get_p_value(test_df, -3.999, "both")[[1]][1], 8/20, tolerance = eps)
   
   expect_equal(
-    get_p_value(test_df, 4, "greater"), get_p_value(test_df, 4, "right")
-  )
-  expect_equal(get_p_value(test_df, 4, "less"), get_p_value(test_df, 4, "left"))
-  expect_equal(
-    get_p_value(test_df, 4, "two_sided"), get_p_value(test_df, 4, "both")
+    get_p_value(test_df, 4, "greater"), 
+    get_p_value(test_df, 4, "right"),
+    tolerance = eps
   )
   expect_equal(
-    get_p_value(test_df, 4, "two-sided"), get_p_value(test_df, 4, "both")
+    get_p_value(test_df, 4, "less"),
+    get_p_value(test_df, 4, "left"),
+    tolerance = eps
   )
   expect_equal(
-    get_p_value(test_df, 4, "two sided"), get_p_value(test_df, 4, "both")
+    get_p_value(test_df, 4, "two_sided"), 
+    get_p_value(test_df, 4, "both"),
+    tolerance = eps
+  )
+  expect_equal(
+    get_p_value(test_df, 4, "two-sided"), 
+    get_p_value(test_df, 4, "both"),
+    tolerance = eps
+  )
+  expect_equal(
+    get_p_value(test_df, 4, "two sided"), 
+    get_p_value(test_df, 4, "both"),
+    tolerance = eps
   )
 })
 
 test_that("theoretical p-value not supported error", {
-  obs_F <- iris_tbl %>% 
-    specify(Sepal.Width ~ Species) %>%
+  obs_F <- gss_tbl %>% 
+    specify(hours ~ partyid) %>%
     calculate(stat = "F") 
   expect_error(
-    iris_tbl %>% 
-      specify(Sepal.Width ~ Species) %>%
+    gss_tbl %>% 
+      specify(hours ~ partyid) %>%
       hypothesize(null = "independence") %>% 
       calculate(stat = "F") %>% 
       get_p_value(obs_stat = obs_F, direction = "right")
